# Generated by Django 3.0 on 2022-07-07 10:25

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("rp", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="species",
            options={"verbose_name_plural": "Species"},
        ),
        migrations.CreateModel(
            name="SpeciesAlias",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("text", models.CharField(max_length=80, unique=True)),
                (
                    "species",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="rp.Species"
                    ),
                ),
            ],
        ),
    ]
